@@ -1,24 +1,10 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 #     Acme::MetaSyntactic::soviet -- NATO codenames for Soviet-designed equipment
+#     Copyright (C) 2008, 2012, 2016 Jean Forget
 #
-#     Copyright (C) 2008, 2012 Jean Forget
+#     See the license in the embedded documentation below.
 # 
-#     This program is free software; you can redistribute it and/or modify
-#     it under the same terms as Perl: either the Artistic License,
-#     or the GNU General Public License as published by
-#     the Free Software Foundation; either version 1, or (at your option)
-#     any later version.
-# 
-#     This program is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-# 
-#     You should have received a copy of the GNU General Public License and
-#     the Artistic License along with this program; if not, write to the Free
-#     Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-#     02111-1307, USA for the GNU General Public License.
 package Acme::MetaSyntactic::soviet;
 
 use warnings;
@@ -26,7 +12,7 @@ use strict;
 
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my $data = { default => 'electronic' };
 my ($category2, $category3);
@@ -80,8 +66,8 @@ Acme::MetaSyntactic::soviet -- NATO codenames for Soviet-designed equipment
 =head1 DESCRIPTION
 
 Some codenames  given by  NATO to Soviet-designed  aircraft, missiles,
-radars  and  other  electronic  systems. The  various  categories  and
-sub-categories are
+submarines,   radars  and  other   electronic  systems.   The  various
+categories and sub-categories are
 
 =over 4
 
@@ -115,6 +101,10 @@ vehicles/missiles
 
 =item *
 
+vehicles/submarines
+
+=item *
+
 vehicles/error
 
 =back
@@ -123,8 +113,8 @@ The default category is 'electronic'.
 
 =head1 VERSION
 
-This  is version  0.03, the  "Foxbat"  version, released  on the  36th
-anniversary of Belenko's flight (flying or fleeing?) to Japan.
+This  is version  0.04, the  "Guideline"  version, released  on the  56th
+anniversary of the downing of Gary Power's U-2 by a SA-2 Guideline.
 
 =head1 SYNOPSIS
 
@@ -140,15 +130,17 @@ read:
 
     my $meta = Acme::MetaSyntactic->new( 'soviet', category => 'vehicle/aircraft' );
 
+If C<meta>  from L<Acme::MetaSyntactic> is  installed, you can  use it
+from the command line:
+
+    meta soviet
+
+    meta soviet/vehicles/submarines
 
 =head1 CONTRIBUTOR
 
 Jean Forget
 
-Not  yet  introduced in  Acme::MetaSyntactic,  but  version 0.01,  the
-"Sandal" version, was published  separately on 23rd October 2008, 46th
-anniversary of the blockade of Cuba.
-
 =head1 SOURCES
 
 Note: I  have used  only sources published  I<before> the fall  of the
@@ -156,47 +148,130 @@ Soviet Union. Therefore, the  module name is C<A::MS::soviet>, with no
 "ex-"  prefix.  For  each entry,  the  sources are  listed, with  page
 numbers for the books. The games use data cards, which are unnumbered.
 
+Some sources, especially early  sources, may contain some errors. Some
+equipment  may appear with  faulty intelligence  reports which  give a
+wrong  code or  description.  And  a later  intelligence  report would
+correct it.  The best  example is the  Backfire, first given  the code
+"Tu-26" and then the code "Tu-22M".
+
+=head2 Main Sources
+
+These sources  contain extensive lists  or extensive tables  of soviet
+equipment.
+
+=over 4
+
+=item *
+
 I<Pat-Led-1>
 written by J-J Patry and P. Lederer
 published by Editions Presse & Recherche
 abbreviated as I<PL>.
 
+=item *
+
 I<Jane's World Aircraft Recognition Handbook>
 written by Derek Wood
 published by Janes in 1987
 (ISBN 0-7106-0343-6)
 abbreviated as I<JWARH>.
 
+=item *
+
 I<Air Superiority>
 designed by J.D. Webster
 and published by GDW in 1987
 (ISBN 0-943580-19-6)
 abbreviated as I<ASu>.
 
+=item *
+
 I<Air Strike>
 designed by J.D. Webster
 and published by GDW in 1987
 (ISBN 0-943580-30-7)
 abbreviated as I<ASt>.
 
+=item *
+
 I<Desert Falcons>
 designed by J.D. Webster
 and published by GDW in 1988
 (ISBN 0-943580-97-8)
 abbreviated as I<DF>.
 
+=item *
+
+I<Les Flottes de Combat 1968>
+written by H. Le Masson
+published by Editions Maritimes et Outre-Mer
+(no ISBN)
+abbreviated as I<LFDC>.
+
+=item *
+
 I<Flottes de Combat 1990>
 written by B. Prézelin
 published by Editions Maritimes et Outre-Mer
 (ISBN 2.7373.0485.7)
 abbreviated as I<FDC>.
 
+Note: these  last two  books are actually  the same book,  updated and
+published every  other year.  You can notice  that the title  has been
+shortened between the 1968 issue and the 1990 issue (FDC vs. LFDC).
+
+=item *
+
 I<Air Wars and Aircraft>
 written by Victor Flintham
 published by Arms and Armour in 1989
 (ISBN 0-85368-779-X)
 abreviated as I<AWA>.
 
+=item *
+
+I<Air War>
+designed by David Isby
+published in 1977 by SPI and then in 1983 by TSR
+(no ISBN)
+abreviated as I<SPIAW>.
+
+=back
+
+=head2 Minor Sources
+
+These  sources  mention some  NATO  codes  for  soviet equipment,  but
+without trying to give an exhaustive list of some category or other.
+
+=over 4
+
+=item *
+
+I<Rolling Thunder>
+designed by Steve Weiss
+published by Group Three Games in 1985
+(no ISBN)
+abreviated as I<RT>.
+
+=item *
+
+I<Fox Two>
+by Randy Cunningham with Jeff Ethell
+published by Warner Books in 1984
+ISBN 0-446-35458-9
+abreviated as I<F2>.
+
+=item *
+
+I<The Hunt for Red October>
+by Tom Clancy,
+first published by Naval Institute Press in 1984
+published by Fontana in 1987
+ISBN 0-00-617276-8
+abreviated at I<THFRO>.
+
+=back
+
 =head1 SOVIET EQUIPMENT
 
 =cut
@@ -220,7 +295,7 @@ Navigation radar, FDC 758.
 
 =item Bar Lock
 
-Warning radar, PL 124.
+Warning radar, PL 124, mentioned in RT.
 
 =item Bass Tilt
 
@@ -282,6 +357,10 @@ Gun control radar, FDC 759.
 
 Target tracking radar, FDC 759.
 
+=item Fan Song
+
+Guidance radar for SA-2 missiles, mentioned in RT.
+
 =item Fire Dome
 
 Gadfly fire control radar, PL 114.
@@ -312,7 +391,7 @@ Submarine mounted radar, FDC 759.
 
 =item Gun Dish
 
-ZSU-23-4 fire control radar, PL 105.
+ZSU-23-4 fire control radar, PL 105, mentioned in RT.
 
 =item Half Cup
 
@@ -763,8 +842,8 @@ Electronic warfare, FDC 760.
 
 =head2 VEHICLES
 
-This category  lists flying  vehicles. These vehicles  are submarines,
-planes, helicopter or missiles.
+This  category lists  flying and  naval vehicles.  These  vehicles are
+submarines, planes, helicopter or missiles.
 
 =head3 SUBMARINES
 
@@ -776,7 +855,7 @@ Nuclear-powered attack submarine (SSN), FDC 790.
 
 =item Alfa
 
-Nuclear-powered attack submarine (SSN), FDC 789.
+Nuclear-powered attack submarine (SSN), FDC 789. A prominent character of THFRO.
 
 =item Beluga
 
@@ -788,15 +867,15 @@ Auxiliary / rescue submarine (SST), FDC 798.
 
 =item Charlie I
 
-Nuclear-powered aerodynamic missile submarine (SSGN), FDC 785.
+Nuclear-powered aerodynamic missile submarine (SSGN), FDC 785. Mentioned in THFRO.
 
 =item Charlie II
 
-Nuclear-powered aerodynamic missile submarine (SSGN), FDC 785.
+Nuclear-powered aerodynamic missile submarine (SSGN), FDC 785. Mentioned in THFRO.
 
 =item Delta I
 
-Nuclear-powered ballistic missile submarine (SSBN), FDC 781.
+Nuclear-powered ballistic missile submarine (SSBN), FDC 781. Mentioned (without number) in THFRO.
 
 =item Delta II
 
@@ -812,7 +891,7 @@ Nuclear-powered ballistic missile submarine (SSBN), FDC 780.
 
 =item Echo
 
-Nuclear-powered attack submarine (SSN), FDC 793.
+Nuclear-powered attack submarine (SSN), FDC 793. Mentioned in THFRO.
 
 =item Echo II
 
@@ -829,7 +908,7 @@ Attack submarine (SS), FDC 795.
 
 =item Golf II
 
-Ballistic missile submarine (SSB), FDC 783.
+Ballistic missile submarine (SSB), FDC 783. Mentioned (without number) in THFRO.
 
 =item Golf II Mod
 
@@ -869,11 +948,11 @@ Tracked rescue submarine, FDC 798.
 
 =item November
 
-Nuclear-powered attack submarine (SSN), FDC 793.
+Nuclear-powered attack submarine (SSN), FDC 793. Mentioned in THFRO.
 
 =item Oscar I
 
-Nuclear-powered aerodynamic missile submarine (SSGN), FDC 784.
+Nuclear-powered aerodynamic missile submarine (SSGN), FDC 784. Mentioned (without number) in THFRO.
 
 =item Oscar II
 
@@ -893,11 +972,11 @@ Nuclear-powered attack submarine (SSN), FDC 790.
 
 =item Tango
 
-Attack submarine (SS), FDC 795.
+Attack submarine (SS), FDC 795. Mentioned in THFRO.
 
 =item Typhoon
 
-Nuclear-powered ballistic missile submarine (SSBN), FDC 779.
+Nuclear-powered ballistic missile submarine (SSBN), FDC 779. A prominent character of THFRO.
 
 =item Uniform
 
@@ -905,11 +984,11 @@ Nuclear-powered auxiliary / rescue submarine (SSAN), FDC 797.
 
 =item Victor I
 
-Nuclear-powered attack submarine (SSN), FDC 793.
+Nuclear-powered attack submarine (SSN), FDC 793. Mentioned in THFRO.
 
 =item Victor II
 
-Nuclear-powered attack submarine (SSN), FDC 792.
+Nuclear-powered attack submarine (SSN), FDC 792. Mentioned in THFRO.
 
 =item Victor III
 
@@ -927,6 +1006,7 @@ Nuclear-powered auxiliary / rescue submarine (SSAN), FDC 798.
 
 Nuclear-powered ballistic missile submarine (SSBN), FDC 782
 or nuclear-powered attack submarine (SSN), FDC 794.
+Mentioned (without number) in THFRO.
 
 =item Yankee II
 
@@ -950,17 +1030,17 @@ Auxiliary / rescue submarine (SSA), FDC 797.
 
 =over 4
 
-=item Badger
-
-Tu-16 bomber, JWARH 37, 93, FDC 774, AWA 392.
-
 =item Backfin
 
 Yak aircraft, number unknown, AWA 392.
 
 =item Backfire
 
-Tu-22M / Tu-26 variable geometry bomber, JWARH 37, 189, FDC 775, AWA 392.
+Tu-22M / Tu-26 variable geometry bomber, JWARH 37, 189, FDC 775, AWA 392, SPIAW.
+
+=item Badger
+
+Tu-16 bomber, JWARH 37, 93, LFDC 368, FDC 774, AWA 392.
 
 =item Bank
 
@@ -976,11 +1056,11 @@ Tu-2, AWA 392.
 
 =item Beagle
 
-Il-28 bomber, JWARH 37, 216, AWA 392.
+Il-28 bomber, JWARH 37, 216, LFDC 368, AWA 392.
 
 =item Bear
 
-Tu-95 bomber or Tu-142 bomber (Bear F and H), JWARH 37, 121, FDC 774, AWA 392.
+Tu-95 bomber or Tu-142 bomber (Bear F and H), JWARH 37, 121, LFDC 368, FDC 774, AWA 392.
 
 =item Beast
 
@@ -996,7 +1076,7 @@ Tu supersonic bomber, JWARH 37, AWA 392.
 
 =item Blinder
 
-Tu-22 bomber, JWARH 37, 132, FDC 774, AWA 392.
+Tu-22 bomber, JWARH 37, 132, LFDC 368, FDC 774, AWA 392.
 
 =item Blowlamp
 
@@ -1016,7 +1096,7 @@ Tu-14, AWA 392.
 
 =item Bounder
 
-M-? (number unknown), AWA 392.
+M-? (number unknown), AWA 392 or Tu-?, LFDC 368.
 
 =item Box
 
@@ -1184,7 +1264,7 @@ An-26 transport aircraft, PL 220, JWARH 38, 286, AWA 392.
 
 =item Fagot
 
-MiG-15bis, JWARH 38, DF, AWA 392.
+MiG-15bis, JWARH 38, DF, AWA 392, SPIAW.
 
 =item Fang
 
@@ -1194,17 +1274,13 @@ La-11 fighter, AWA 392.
 
 La-15 fighter, AWA 392.
 
-=item Fagot
-
-MiG-15 fighter, AWA 392.
-
 =item Fargo
 
 MiG-9 fighter, AWA 392.
 
 =item Farmer
 
-MiG-19 fighter, PL 213, JWARH 38, 56, DF, AWA 392.
+MiG-19 fighter, PL 213, JWARH 38, 56, DF, AWA 392, SPIAW.
 
 =item Feather
 
@@ -1212,7 +1288,7 @@ Yak-17 fighter, AWA 392.
 
 =item Fencer
 
-Su-24 variable geometry strike fighter, PL 211, JWARH 38, 187, ASt, AWA 392.
+Su-24 variable geometry strike fighter, PL 211, JWARH 38, 187, ASt, AWA 392. Or Su-19 according to SPIAW.
 
 =item Fiddler
 
@@ -1228,7 +1304,7 @@ Yak-28 fighter, PL 222, JWARH 38, 98, AWA 392.
 
 =item Fishbed
 
-MiG-21 fighter, PL 211, JWARH 38, 177, ASu, DF, AWA 392.
+MiG-21 fighter, PL 211, JWARH 38, 177, ASu, DF, AWA 392, SPIAW.
 
 =item Fishpot
 
@@ -1237,11 +1313,11 @@ Su-9/Su-11 fighter, PL 222, JWARH 38, 176, AWA 392.
 =item Fitter
 
 Su-7 fighter (Fitter A) or Su-17/20/22 variable geometry fighter (Fitter C and D) or
-Su-17 fighter (Fitter K), PL 212, JWARH 38, 57, 186, ASu, FDC 775, AWA 392.
+Su-17 fighter (Fitter K), PL 212, JWARH 38, 57, 186, ASu, FDC 775, AWA 392, SPIAW.
 
 =item Flagon
 
-Su-21 fighter aircraft, PL 222. Or Su-15 fighter, JWARH 38, 175, ASu, DF, AWA 392.
+Su-21 fighter aircraft, PL 222. Or Su-15 fighter, JWARH 38, 175, ASu, DF, AWA 392, SPIAW.
 
 =item Flanker
 
@@ -1254,7 +1330,7 @@ Yak-25 and Yak-27 fighters, AWA 392.
 =item Flogger
 
 MiG-23 variable geometry fighter (Flogger A and G) or MiG-27 variable geometry
-fighter (Flogger D and J), PL 210, JWARH 38, 184, 185, ASu, ASt, DF, AWA 392.
+fighter (Flogger D and J), PL 210, JWARH 38, 184, 185, ASu, ASt, DF, AWA 392, SPIAW.
 
 =item Flora
 
@@ -1262,11 +1338,11 @@ Yak-23 fighter, AWA 392.
 
 =item Forger
 
-Yak-38 VSTOL fighter, PL 214, JWARH 38, 64, FDC 775, AWA 392.
+Yak-38 VSTOL fighter, PL 214, JWARH 38, 64, FDC 775, AWA 392. Mentioned in THFRO.
 
 =item Foxbat
 
-MiG-25 interceptor, PL 223, 224, JWARH 38, 85, DF, AWA 392.
+MiG-25 interceptor, PL 223, 224, JWARH 38, 85, DF, AWA 392, SPIAW.
 
 =item Foxhound
 
@@ -1282,7 +1358,7 @@ Lend-lease P-63 fighter, AWA 392.
 
 =item Fresco
 
-MiG-17 fighter, PL 213, JWARH 38, 55, DF, AWA 392.
+MiG-17 fighter, PL 213, JWARH 38, 55, DF, AWA 392, SPIAW.
 
 =item Fritz
 
@@ -1298,7 +1374,7 @@ MiG-29 fighter, PL 208, JWARH 38, 87, ASu, AWA 392.
 
 =item Madge
 
-Be-6 flying boat, JWARH 38, AWA 392.
+Be-6 flying boat, JWARH 38, LFDC 368, AWA 392.
 
 =item Maestro
 
@@ -1432,6 +1508,10 @@ Mi-1 / Mi-3 light helicopter, JWARH 38, 509, AWA 392.
 
 Mi-10 heavy transport helicopter, PL 202, JWARH 38, 539, AWA 392.
 
+=item Harp
+
+Ka-20 ASW helicopter, LFDC 368.
+
 =item Havoc
 
 Mi-28 attack helicopter, PL 198, JWARH 38, AWA 392.
@@ -1486,11 +1566,11 @@ Ka-25 naval helicopter, JWARH 38, 541, FDC 775, AWA 392.
 
 =item Horse
 
-Yak-24, AWA 392.
+Yak-24, LFDC 368, AWA 392.
 
 =item Hound
 
-Mi-4  medium transport and support helicopter, PL 204, JWARH 38, 515, AWA 392.
+Mi-4  medium transport and support helicopter, PL 204, JWARH 38, 515, LFDC 368, AWA 392.
 
 =back
 
@@ -1507,7 +1587,7 @@ the same.
 
 =item Acrid
 
-AA-6 air-to-air missile, PL 223, JWARH 30, DF.
+AA-6 air-to-air missile, PL 223, JWARH 30, DF, SPIAW.
 
 =item Alamo
 
@@ -1515,7 +1595,7 @@ AA-10 air-to-air missile, PL 225, ASu, DF.
 
 =item Alkali
 
-AA-1 air-to-air missile, PL 213.
+AA-1 air-to-air missile, PL 213, SPIAW.
 
 =item Amos
 
@@ -1523,15 +1603,15 @@ AA-9 air-to-air missile, PL 224, ASu.
 
 =item Anab
 
-AA-3 air-to-air missile, PL 222, JWARH 29, ASu.
+AA-3 air-to-air missile, PL 222, JWARH 29, ASu, SPIAW.
 
 =item Apex
 
-AA-7 air-to-air missile, PL 208, 210, 211, 224, JWARH 29, ASu.
+AA-7 air-to-air missile, PL 208, 210, 211, 224, JWARH 29, ASu, SPIAW.
 
 =item Aphid
 
-AA-8 air-to-air missile, PL 208, 210, 211, 214, 224, JWARH 29, ASu.
+AA-8 air-to-air missile, PL 208, 210, 211, 214, 224, JWARH 29, ASu, SPIAW.
 
 =item Archer
 
@@ -1543,7 +1623,7 @@ AA-5 air-to-air missile, PL 223, JWARH 29, DF.
 
 =item Atoll
 
-AA-2 air-to-air missile, PL 210, 213, 222, JWARH 30, DF.
+AA-2 air-to-air missile, PL 210, 213, 222, JWARH 30, DF, SPIAW. Mentioned in RT, F2 and THFRO.
 
 =item Frog
 
@@ -1555,7 +1635,7 @@ SA-11 / SA-N-7 anti-aircraft missile, PL 114, FDC 755.
 
 =item Gainful
 
-SA-6 ground-to-air missile, PL 118.
+SA-6 ground-to-air missile, PL 118, SPIAW.
 
 =item Ganef
 
@@ -1575,7 +1655,7 @@ SA-12 ground-to-air missile, PL 114.
 
 =item Goa
 
-SA-N-1 anti-aircraft missile, FDC 755.
+SA-N-1 anti-aircraft missile, LFDC 367, FDC 755, SPIAW.
 
 =item Goblet
 
@@ -1587,7 +1667,7 @@ SA-13 ground-to-air missile, PL 113.
 
 =item Grail
 
-SA-7 / SA-N-5 anti-aircraft missile, FDC 755.
+SA-7 / SA-N-5 anti-aircraft missile, FDC 755, SPIAW. RT gives a Russian name, I<Strela>.
 
 =item Gremlin
 
@@ -1597,9 +1677,14 @@ SA-14 / SA-N-8 anti-aircraft missile, FDC 755.
 
 SA-10 / SA-N-6 anti-aircraft missile, PL 115, FDC 755.
 
+=item Guideline
+
+SA-2 / SNA-1 anti-aircraft missile, LFDC 367, SPIAW.
+
 =item Kangroo
 
 AS-3 air-to-ground missile (surely a typo for kangaroo), JWARH 25.
+Note: LFDC 367 gives the name with a French spelling: "Kangourou".
 
 =item Karen
 
@@ -1613,6 +1698,10 @@ AS-14 air-to-ground missile, PL 211, 226.
 
 AS-5 air-to-ground missile, JWARH 25, FDC 756.
 
+=item Kennel
+
+AS-1 air-to-surface missile, LFDC 367.
+
 =item Kent
 
 AS-15 air-to-ground missile, FDC 756.
@@ -1627,11 +1716,11 @@ AS-6 air-to-ground missile, FDC 756, named Kingfisher by JWARH 25.
 
 =item Kipper
 
-AS-2 air-to-ground missile, JWARH 25, FDC 756.
+AS-2 air-to-ground missile, JWARH 25, LFDC 367, FDC 756.
 
 =item Kitchen
 
-AS-4 air-to-ground missile, FDC 756.
+AS-4 air-to-ground missile, LFDC 367, FDC 756.
 
 =item Kyle
 
@@ -1739,11 +1828,11 @@ SS-N-18 ballistic missile, FDC 754.
 
 =item Sturgeon
 
-SS-N-20 ballistic missile, FDC 754.
+SS-N-20 ballistic missile, FDC 754. THFRO gives it the name "Seahawk".
 
 =item Styx
 
-SS-N-2 anti-ship missile, FDC 754.
+SS-N-2 anti-ship missile, LFDC 367, FDC 754.
 
 =item Sunburn
 
@@ -1813,16 +1902,47 @@ L<http://cpanratings.perl.org/d/Acme-MetaSyntactic-soviet>
 
 L<http://search.cpan.org/dist/Acme-MetaSyntactic-soviet>
 
+=item * MetaCPAN
+
+L<https://metacpan.org/pod/Acme::MetaSyntactic::soviet>
+
+=item * GitHub
+
+L<https://github.com/jforget/Acme-MetaSyntactic-soviet>
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008, 2012 Jean Forget, all rights reserved.
+Copyright  2008, 2012, 2016  Jean Forget,  all rights  reserved.  This
+program is  free software;  you can redistribute  it and/or  modify it
+under the same  terms as Perl itself: GNU Public  License version 1 or
+later and Perl Artistic License.
 
-This program is free software; you can redistribute it and you can modify it
-under the same terms as Perl itself.
+The full text of the license can be found in the F<LICENSE> file included
+with this module or at
+L<http://www.perlfoundation.org/artistic_license_1_0> and
+L<http://www.gnu.org/licenses/gpl-1.0.html>.
+
+Here is the summary of GPL:
+
+This program is  free software; you can redistribute  it and/or modify
+it under the  terms of the GNU General Public  License as published by
+the Free  Software Foundation; either  version 1, or (at  your option)
+any later version.
+
+This program  is distributed in the  hope that it will  be useful, but
+WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
+MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+General Public License for more details.
+
+You  should have received  a copy  of the  GNU General  Public License
+along with this program; if not, see <http://www.gnu.org/licenses/> or
+write to the Free  Software Foundation, Inc., L<http://fsf.org>.  This
+program is free  software; you can redistribute it  and you can modify
+it under the same terms as Perl itself.
 
 =cut
 
